@@ -33,12 +33,10 @@
 //!      pg-embed = "0.5"
 //!      ```
 //!
-//! A postgresql instance can be created using<br/>
-//! **[PgEmbed]( postgres::PgEmbed )::new([PgSettings]( postgres::PgSettings ), [PgFetchSettings]( fetch::PgFetchSettings ))**
 //!
 //! # Examples
 //!
-//! ```
+//! ```rust, ignore
 //!
 //! use pg_embed::postgres::{PgEmbed, PgSettings, PgAuthMethod};
 //! use pg_embed::pg_fetch;
@@ -75,33 +73,33 @@
 //!
 //! /// async block only to show that these methods need to be executed in an async context
 //! async {
-//! // Create a new instance
-//! let mut pg = PgEmbed::new(pg_settings, fetch_settings).await?;
+//!      // Create a new instance
+//!      let mut pg = PgEmbed::new(pg_settings, fetch_settings).await?;
 //!
-//! // Download, unpack, create password file and database cluster
-//! pg.setup().await;
+//!      // Download, unpack, create password file and database cluster
+//!      pg.setup().await;
 //!
-//! // start postgresql database
-//! pg.start_db().await;
+//!      // start postgresql database
+//!      pg.start_db().await;
 //!
-//! // create a new database
-//! // to enable migrations view the [Usage] section for details
-//! pg.create_database("database_name").await;
+//!      // create a new database
+//!      // to enable migrations view the [Usage] section for details
+//!      pg.create_database("database_name").await;
 //!
-//! // drop a new database
-//! // to enable migrations view [Usage] for details
-//! pg.drop_database("database_name").await;
+//!      // drop a database
+//!      // to enable migrations view [Usage] for details
+//!      pg.drop_database("database_name").await;
 //!
-//! // check database existence
-//! // to enable migrations view [Usage] for details
-//! pg.database_exists("database_name").await;
+//!      // check database existence
+//!      // to enable migrations view [Usage] for details
+//!      pg.database_exists("database_name").await;
 //!
-//! // run migration sql scripts
-//! // to enable migrations view [Usage] for details
-//! pg.migrate("database_name").await;
+//!      // run migration sql scripts
+//!      // to enable migrations view [Usage] for details
+//!      pg.migrate("database_name").await;
 //!
-//! // stop postgresql database
-//! pg.stop_db().await;
+//!      // stop postgresql database
+//!      pg.stop_db().await;
 //! };
 //! // get the base postgresql uri
 //! // `postgres://{username}:{password}@localhost:{port}`
@@ -114,6 +112,24 @@
 //!
 //!
 //! ```
+//! ## Info
+//!
+//! The downloaded postgresql binaries are cached in the following directories:
+//!
+//!   - On Linux:
+//!
+//!     `$XDG_CACHE_HOME/pg-embed`
+//!
+//!     or
+//!
+//!     `$HOME/.cache/pg-embed`
+//!   - On Windows:
+//!
+//!     `{FOLDERID_LocalAppData}/pg-embed`
+//!   - On MacOS:
+//!
+//!     `$HOME/Library/Caches/pg-embed`
+//!
 //!
 //! ## Recent Breaking Changes
 //!
@@ -130,13 +146,16 @@
 //! Reliant on the great work being done by [zonkyio/embedded-postgres-binaries](https://github.com/zonkyio/embedded-postgres-binaries) in order to fetch precompiled binaries from [Maven](https://mvnrepository.com/artifact/io.zonky.test.postgres/embedded-postgres-binaries-bom).
 //!
 
+extern crate dirs;
+#[macro_use]
+extern crate lazy_static;
 #[cfg(not(any(
-feature = "rt_tokio_migrate",
-feature = "rt_tokio",
-feature = "rt_actix_migrate",
-feature = "rt_actix",
-feature = "rt_async_std_migrate",
-feature = "rt_async_std",
+    feature = "rt_tokio_migrate",
+    feature = "rt_tokio",
+    feature = "rt_actix_migrate",
+    feature = "rt_actix",
+    feature = "rt_async_std_migrate",
+    feature = "rt_async_std",
 )))]
 compile_error!(
     "one of the features ['rt_tokio_migrate', 'rt_tokio', \
@@ -145,22 +164,22 @@ compile_error!(
 );
 
 #[cfg(any(
-all(feature = "rt_tokio", feature = "rt_async_std"),
-all(feature = "rt_tokio", feature = "rt_async_std_migrate"),
-all(feature = "rt_tokio_migrate", feature = "rt_async_std"),
-all(feature = "rt_tokio_migrate", feature = "rt_async_std_migrate"),
+    all(feature = "rt_tokio", feature = "rt_async_std"),
+    all(feature = "rt_tokio", feature = "rt_async_std_migrate"),
+    all(feature = "rt_tokio_migrate", feature = "rt_async_std"),
+    all(feature = "rt_tokio_migrate", feature = "rt_async_std_migrate"),
 ))]
 compile_error!(
     "only one of ['rt_tokio', 'rt_tokio_migrate', \
      'rt_async_std', 'rt_async_std_migrate'] can be enabled"
 );
 
-extern crate dirs;
-pub mod pg_fetch;
-pub mod postgres;
+pub mod command_executor;
 pub mod pg_access;
+pub mod pg_commands;
 pub mod pg_enums;
-pub mod pg_unpack;
 pub mod pg_errors;
-#[macro_use]
-extern crate lazy_static;
+pub mod pg_fetch;
+pub mod pg_types;
+pub mod pg_unpack;
+pub mod postgres;
